"""Dir (album) class.

Cy assumes that usually you have a single album in a given directory, and tries to set
the name accordingly; if it's not, nothing horrible happens, but the name may turn out
strange.
"""

import os
import string
import avkutil

avkutil.dbg = 1
debug = avkutil.debug


class Album:
    def __init__(self, path, tracks):
        """Directory holds a list of tracks as self.tracks.

        Comment: now we have to create a good name for the
        directory; it'll be shown in directory list. Typically, we
        have 3 possible arrangements to parse: 1) "artist - album"/
        2) artist/album 3) 1 or 2 + /vol1/. We have to turn this
        into artist - album (vol1).
        """

        self.tracks = tracks
        self.path = os.path.join(os.getcwd(), path)
        if path == '/':
            self.name = path
            return
        vol = None
        tmp = path.split('/')[-3:]
        tmp.reverse()
        t0 = tmp[0].lower()
        if t0.startswith("cd"):
            if len(t0) > 2 and t0[2] in string.digits:
                vol = t0
                del tmp[0]
        elif t0.startswith("vol"):
            if len(t0) > 3 and t0[3] in string.digits:
                vol = t0
                del tmp[0]
        if tmp[0].find(" - ") > -1:
            name = tmp[0]
        else:
            album = tmp[0]
            del tmp[0]
            artist = None
            name = album
            if tmp:
                artist = tmp[0]
                if artist.lower().find("mp3") == -1:
                    name = "%s - %s" % (artist, album)
        if vol:
            name += " (%s)" % vol
        self.name = name


    def remove(self, index):
        del self.tracks[index]

    def __len__(self):
        return len(self.tracks)

    def __str__(self):
        # this is to deal with some names that use foreign characters &
        # terminal sometimes does odd things with those..
        return repr(self.name)[1:-1]

    def __getitem__(self, index):
        return self.tracks[index]
