"""
Cymbaline - console intelligent learning (weighted playlists) media
player.

Usage: 
    cymbaline.py                 - start with last playlist
    cymbaline.py /dir_with_mp3s/ - create a playlist
    cymbaline.py playlist_name   - load a playlist

    Arguments:
        -h, --help              this help message
        -v, --version           version info
"""

from avkutil import color
import main
from colors import colors
import ui
import conf

def main():
    """Print help screen"""

    ui.tracks_window = 0
    ui.do_clear = 1
    s = color("\t\tHelp", colors.help_title)
    s += color(
    """
    s           -   Stop/Start
    n,space     -   Next
    p           -   Previous
    N,P         -   skip to last/first track in album
    j,k         -   skip to next/previous album
    J,K         -   skip to last/first album
    z           -   pause
    []          -   seek back/forward
    /           -   find track matching given pattern
    l{ap}       -   List: Albums, Playlists
    Enter       -   track list; Refresh screen
    Y           -   shortcut for la command (list albums)
    N{gnpasT}   -   go to Nth track; skip N tracks ahead, back;
                    go to Nth album; set score; set threshold
    N{jk}       -   skip N dirs ahead/back
    T           -   Toggle threshold between 0 and 50
    m{rpc}      -   Modes: Random, Play, Continuous
    ,.<>        -   volume down 5 units, up 5, down 10, up 10
    H           -   show advanced commands
    q           -   Quit, stop listing during la or dl commands""", colors.help_body)
    ui.fsdisplay(s)

#    i           -   track info (id3,bitrate,filename)
#    L{OA}       -   Load playlist replacing current/adding to current.
# c         -   reload colors
# int       -   set interval between songs (#int=4m or #int=1s)
# i         -   view image art in current dir
# l         -   view lyrics in current dir
# sl        -   set random slope (e.g. # sl=3) 0 < sl < 6
# stat      -   score file statistics
# all stat  -   statistics for full score file
# 3{dtac}   -   set id3 tags: album&artist for all dir; just the
#                title; all fields; clear titles in dir
# favcd     -   copy highest scoring files in playlist to a separate
#                directory for burning the "favorite tracks cd"
# rmdir     -   remove current directory from disk
# ds          -   display status (print some info)
# D           -   delete current track from disk
# $3c         -   clear id3 tag
# $3d         -   set id3 tag for all tracks in dir
# $3t         -   set id3 title
# $3a         -   set all id3 fields for current file 
# C           -   load mp3s from /cdrom to playlist


def advanced():
    ui.tracks_window = 0
    ui.do_clear = 1
    s = color("\t\tAdvanced commands", colors.help_title)
    s += color("""\t
    w           -   save current playlist
    i           -   Info: id3 tags, path
    e           -   rEpeat last command
    rq          -   Turn on random queue or reload it
    dq          -   Delete entries from Queue
    o           -   play next track with high scOre (see README)
    u           -   change track's score Up to 75 (shorthand for 75s)
    L           -   set track's score to 10
    R           -   Reload playlist from disk
    F           -   write current playlist to an html File
    a           -   About screen
    D           -   delete file from DISK, NO CONFIRMATION
    $allstat    -   score STATistics
    $sl         -   set random SLope
    $rmdir      -   ReMove DIRectory
    $favcd      -   copy tracks with highest scores to a dir
    $i          -   set interval (pause) between tracks
    """, 
        colors.help_body)
    ui.fsdisplay(s)


def about():
    ui.tracks_window = 0
    ui.do_clear = 1
    s = color("\t\tAbout: Cymbaline v" + conf.__version__, colors.help_title)
    s += color("""\t
    Cymbaline is an intelligent learning console music player written
    in python language.

    You can get updates, docs, etc. at: http://silmarill.org/cymbaline.htm

    Andrei Kulakov <ak@silmarill.org>
    """, colors.help_body)
    ui.fsdisplay(s)

def usage():
    print __doc__
