"""Cymbaline key bindings

# id3
clear_id3           - clear id3 tags for ALL files in current dir
id3dir              - set all album/artist id3 tags in dir
id3title            - set id3 title field
id3all              - set all id3 fields for current track
info                - song info: id3, filename, bitrate

# scores
set_slope           - random slope (see README)
play_high_score     - play next high scored track
toggle_threshold    - Toggles threshold between 0 and 50.
score_75            - change current track's score to 75

# file operations
rmdir               - remove current dir (album) from disk
favcd               - create a dir to be burned to "favorites" cd
decode              - decode current dir to wavs
delete              - delete current track from DISK
                        from highest scoring tracks

reload_colors       - reload color conf file
lyrics              - show lyrics in current dir
images              - show album images in current dir

# statistics
statistics          - score statistics for current playlist
all_stat            - statistics for full scorefile

# playlist commands
full_list           - list all tracks
small_list          - list tracks in current dir
add_playlist        - add songs from playlist to current
replace_playlist    - replace current playlist with given
random_queue        - see README

# modes
rand_no_repeat      - play random tracks util queue is empty
stop_after_one      - play one track and stop
stop_after_dir      - play one dir and stop
random_dir          - when dir is finished, pick a random one

# misc
find                - find track by given pattern
about               - about screen
cdrom               - load tracks from cdrom
"""

from player import player
from scores import scores
from stats import stats
from data import data
import modes
import ui
import rand
import misc
import help
from colors import colors

# don't do full screen redraw after these commands
no_redraw = """quit help.about pl.list_albums pl.list_playlists pl.save avkutil.vol misc.volup
    misc.voldown help.main stats.playlist stats.all help.advanced id3.info""".split()


bindings = {
#    "$c"       : colors.load,
    "$sl"      : "pl.setslope",
    "$rmdir"   : "misc.rmdir",
    "$stat"    : "stats.playlist",

    "$allstat" : "stats.all",
    "$3c"      : "id3.clear",
    #"$3d"      : "id3.dir",
    "$favcd"   : "misc.favcd",
    "$3t"      : "id3.title",
    "$3a"      : "id3.all",
    "$i"       : "pl.interval",

# N is the number given before this command
    "<n>g"     : "pl.Nth",
    "<n>n"     : "pl.next",
    "<n>p"     : "pl.prev",
    "<n>j"     : "pl.next_album",
    "<n>k"     : "pl.prev_album",
    "<n>d"     : "pl.Nth_album",
    "<n>s"     : "scores.set",
    "<n>t"     : "pl.set_threshold",


# playback control
    "s"        : "player.play_stop",
    "z"        : "player.pause",
    "<space>"  : "pl.manual_next",
    "n"        : "pl.manual_next",
    "p"        : "pl.prev",
    "N"        : "pl.last",
    "P"        : "pl.first",
    "j"        : "pl.next_album",
    "k"        : "pl.prev_album",
    "J"        : "pl.last_album",
    "K"        : "pl.first_album",
    "o"        : "pl.find_highscore",
    "["        : "player.rewind",
    "]"        : "player.fforward",

# playlist commands
    "F"        : "pl.html",
    "la"       : "pl.list_albums",
    "Y"        : "pl.list_albums",
    "lp"       : "pl.list_playlists",
#    "LO"       : "pl.load",
    "w"        : "pl.save",
    "R"        : "pl.reload",
    "rq"       : "rand.reload_queue",
#    "e"       : "random_queue",

# modes
    "mr"       : "modes.random",
    "mp"       : "modes.play",
    "mt"       : "modes.no_repeat",
    "mc"       : "modes.continuous",

# volume
    #"v"        : "avkutil.vol",
    "."        : "misc.volup",
    ","        : "misc.voldown",

# misc
    "e"        : "",
    "dq"       : "rand.queue_del",
    "T"        : "pl.toggle_threshold",
    "/"        : "pl.find",
    "a"        : "help.about",
    "D"        : "misc.delete",
#    "C"        : "pl.cdrom",
    "u"        : "scores.score75",
    "L"        : "scores.score10",
#    "E"        : "misc.decode",
    "i"        : "id3.info",
    "h"        : "help.main",
    "H"        : "help.advanced",
    "q"        : "quit",
}
