import random
import conf
from data import data

lastrand = []
fullrandlist = []


def add_lastrand(track):
    """Add track to last random list. 
    
    Random list keeps track of which random songs were played
    recently so as not to play them again too soon.
    """

    lastrand.append(track)
    if len(lastrand) > conf.lastrand:
        del lastrand[0]


def mk_randlist():
    """Create random list.

    When in random-no-repeat mode, we create a random playlist and
    play it till it's exhausted; then we create it again.
    """

    ai = i = 0
    from playlist import pl
    for album in pl.albums:
        for track in album.tracks:
            data.randlist.append((ai, i))
            i += 1
        i = 0
        ai += 1
    random.shuffle(data.randlist)


def ls_random():
    from playlist import pl
    for ai, i in data.randlist[:15]:
        print pl.albums[ai][i].name
    return ''


def random_norepeat():
    """Pick random track, deleting it from random list."""
    from playlist import pl
    di, i = data.randlist.pop()
    pl.update(di, i)
    from player import player
    player.play()


def rand(play=1, quantity=1):
    """Pick random track, preferrably a high-scored one.
    
    quantity means how many random tracks to return."""
    di = i = 0
    lst = []
    # how long does this take? profile. If cached, I'd have to update
    # scores in cache..
    from playlist import pl
    for album in pl.albums:
        for track in album.tracks:
            score = track.score() or conf.def_score
            lst.append((score, di, i))
            i += 1
        i = 0
        di += 1
    runs = 0
    rand_list = []
    while 1:
        n = 0
        s = random.randrange(0, data.randslope)
        n = random.randrange(n, 101)
        left = 100 - n
        cutoff = n + left*s/20.0
        s, di, i = random.choice(lst)
        if (s >= cutoff and (di, i) not in lastrand) or runs>5000:
            if rand_list:
                last = rand_list[-1]
                if (last[1], last[2]) == (di, i):
                    # don't need track to play two times in a row!
                    continue
            rand_list.append((pl.albums[di][i], di, i))
            if len(rand_list) >= quantity:
                break
        runs += 1
    if play:
        from player import player
        pl.update(di, i)
        add_lastrand((di, i))
        player.play()
    else:
        return rand_list


def queue():
    from playlist import pl
    import ui
    ui.doredraw = 0
    qmax = 40
    qsize = len(data.queue)
    data.queue.extend(rand(play=0, quantity=(qmax-qsize)))
    tmp = data.queue[0]
    pl.update(tmp[1], tmp[2])
    ui.doredraw = 1
    from player import player
    player.play()


def reload_queue():
    data.random = 'queue'
    data.queue = []
    queue()
    from player import player
    player.play()


def queue_del():
    """ Delete entries from random queue."""
    import ui
    while 1:
        ui.doredraw = 0
        num = ui.ask("Number of track to remove: ")
        if not num:
            break
        try:
            inum = int(num)
        except:
            continue
        del data.queue[inum-1]
        queue()
        ui.doredraw = 0
        ui.fullredraw()
    ui.doredraw = 1


def random_album():
    """Pick random album, preferring one with high-scoring tracks."""
    lst = []
    albumindex = 0
    from playlist import pl
    for album in pl.albums:
        albumscore = 0
        for track in album.tracks:
            trackscore = track.score()
            if not trackscore:
                albumscore += conf.def_score
            else:
                albumscore += trackscore
        score_avg = albumscore / len(album.tracks)
        album = albumindex, score_avg
        lst.append(album)
        albumindex += 1
    runs = 0
    while 1:
        n = -5
        for i in range(data.randslope):
            n = random.randrange(n, 101)
        di, s = random.choice(lst)
        if s >= n or runs > 50: break
        runs += 1
    pl.update(di, 0)
    from player import player
    player.play()
