"""Cymbaline User Interface."""

import curses
from types import *
import sys
import string
import threading
import time
import avkutil
from data import data
from colors import colors
from status import stat
from debug import debug
from cycurses import cycurses


screen = []         # list containing all lines on screen
doredraw = 1
tmpcmd = ''         # before cmd is complete, chars are stored here
do_clear = 0
tracks_window = 1   # currently showing window with track list

def mk_rlock():
    global rlock
    rlock = threading.RLock()


def choose(lst):
    """Choose an item out of the list."""
    # TODO not used anywhere? remove

    h, w = t.size()
    min_width = 30          # min entry width, including padding
    cols = w / min_width
    width = round(w/cols)
    num = cols * (h-1)      # number of items in a screenful

    while 1:
        n = 0
        scr, lst = lst[:num], lst[num:]
        text = []
        for i in range(h-1):
            row = ""
            for j in range(cols):
                item = n + j*(h-1)
                row += "%d) %s  " % (i+1, scr[item][:width-6])
            n += 1
            text.append(row)
        a = ask("'h' for help. > ")
        if a == 'h':
            display("Enter a number to pick an item; 'q' to return.")
        elif a == 'q':
            return
        else:
            try:
                return scr[int(a)-1]
            except ValueError:
                stat.error("Invalid input!")


def clear_progress():
    # don't need anymore? because of rlock?
    print_line(h()-1, [(' '*(w()-1), colors.default)])


def clear():
    cycurses.win.clear()

def redraw():
    """Redraw progress bar and the prompt."""
    from player import player
    if doredraw:
        debug( 'PROGRESS')
        debug( player.progress())
        text = player.progress() + prompt()
        print_line(h()-1, text)
        refresh()

def refresh():
    rlock.acquire()
    cycurses.win.refresh()
    rlock.release()

def size():
    return cycurses.win.getmaxyx()


def h():
    return size()[0]


def w():
    return size()[1]


def ask(question):
    global doredraw
    doredraw = 0
    cw = cycurses.win
    cw.addnstr(h()-1, 0, question.ljust(w()-1), w()-1)
    refresh()
    import curses
    curses.echo(1)
    answer = cw.getstr(h()-1, len(question))
    curses.echo(0)
    doredraw = 1
    return answer


def fullredraw(text=None):
    """Redraw screen."""
    import rand
    if not doredraw: return
    from playlist import pl
    if not text:
        pl.ls()
    else:
        for i in range(len(text)):
            cycurses.win.addnstr(i, 0, text[i], w()-1)
    status_bar()
    redraw()


def print_line(y, text):
    '''y is y-coord; text is a list of tuples - (text, color) or one tuple.
    '''
    if type(text) == type(()):
        text = [text]
    fulltxt = ''
    win = cycurses.win
    win.addnstr(y, 0, ' '*(w()-1), w()-1)
    for txt, color in text:
        if curses.has_colors():
            win.addstr(y, len(fulltxt), txt, color)
        else:
            win.addstr(y, len(fulltxt), txt)
        fulltxt += txt


def status_bar():
    y = h()-2
    text = []
    text.append(('thres ', colors.default))
    text.append(('[%s] ' % data.threshold, colors.options))
    text.append(('play ', colors.default))
    text.append(('[%s] ' % data.play, colors.options))
    if data.continuous: cont = 'on'
    else: cont = 'off'
    text.append(('continuous ', colors.default))
    text.append(('[%s] ' % cont, colors.options))
    text.append(('random ', colors.default))
    text.append(('[%s] ' % data.random, colors.options))
    text.append(('slope ', colors.default))
    text.append(('[%s] ' % data.randslope, colors.options))
    print_line(h()-2, text)


def fsdisplay(msg):
    """Full screen display.

    Clear full screen and display messages.
    """

    #lst = [''] + msg.split('\n')
    #l = len(lst)
    #height = h()
    #lst.extend(['']*(height-l-1))
    cycurses.win.clear()
    fullredraw(msg.split('\n'))


def prompt():
    """[p] > """
    from player import player
    if player.mode == "play":
        colr = colors.playing
        char = '>'
    elif player.mode == "stop":
        colr = colors.stopped
        char = 's'
    elif player.mode == "pause":
        colr = colors.paused
        char = 'z'
    pr_col = colors.prompt_brackets
    return [(' [', pr_col),  (char, colr),  (']', pr_col), (' %s' % tmpcmd,
        colors.default)]


def mouse(y):
    if data.random == 'queue':
        pl.next(y-1)
    else:
        pl.Nth(y-2)


def uinput():
    """User input.

    This function has to deal with 3 types of commands: normal (one
    or more letters; extended (starts with # and goes into
    raw_input()); and <num>command.

    Returns (type, command) tuple. Type is 'n' for normal and
    extended; 'N' for number commands; for these command is a tuple
    (number, command).
    """

    import key
    global tmpcmd, do_clear
    tmpcmd = ''
    num = ''
    chars = ''
    while 1:
        ch = None
        if ch == curses.KEY_MOUSE:
            _, _, y, _, _ = curses.getmouse()
            mouse(y)
            debug('mouse! ' + str(y) + '\n')
            continue
        #c = curses.keyname(ch)
        c = cycurses.win.getkey()
        debug('char is "%s"' % c)
        if c == '\n':
            do_clear = 1
            return None
        if c == ' ':
            return 'n', None, "<space>"
        elif c == '$':
            cmd = ask('$ ')
            return 'n', None, c + cmd
        elif len(c) == 1 and c in string.digits:
            num += c
        else:
            if num:
                return 'N', int(num), c
            else:
                chars += c
                if key.bindings.has_key(chars):
                    return 'n', None, chars


def cl():
    """Clear line."""
    pass
